.minimalist{position:relative;width:100%;background-size:contain;background-repeat:no-repeat;background-position:center center;display:inline-block;}
.minimalist *{font-weight:inherit;font-family:inherit;font-style:inherit;text-decoration:inherit;font-size:100%;padding:0;border:0;margin:0;list-style-type:none}
.minimalist a:focus{outline:0}
.minimalist video{width:100%}
.minimalist.is-ipad video{-webkit-transform:translateX(-2048px);}
.is-ready.minimalist.is-ipad video{-webkit-transform:translateX(0)}
.minimalist .fp-engine,.minimalist .fp-ui,.minimalist .fp-message{position:absolute;top:0;left:0;width:100%;height:100%;cursor:pointer;z-index:1}
.minimalist .fp-message{display:none;text-align:center;padding-top:5%;cursor:default;}
.minimalist .fp-message h2{font-size:120%;margin-bottom:1em}
.minimalist .fp-message p{color:#666;font-size:95%}
.minimalist .fp-controls{position:absolute;bottom:0;width:100%;}
.no-background.minimalist .fp-controls{background-color:transparent !important;background-image:-moz-linear-gradient(transparent,transparent) !important;background-image:-webkit-gradient(linear,0 0,0 100%,from(transparent),to(transparent)) !important}
.is-fullscreen.minimalist .fp-controls{bottom:3px}
.is-mouseover.minimalist .fp-controls{bottom:0}
.minimalist .fp-waiting{display:none;margin:19% auto;text-align:center;}
.minimalist .fp-waiting *{-webkit-box-shadow:0 0 5px #333;-moz-box-shadow:0 0 5px #333;box-shadow:0 0 5px #333}
.minimalist .fp-waiting em{width:1em;height:1em;-webkit-border-radius:1em;-moz-border-radius:1em;border-radius:1em;background-color:rgba(255,255,255,0.8);display:inline-block;-webkit-animation:pulse .6s infinite;-moz-animation:pulse .6s infinite;animation:pulse .6s infinite;margin:.3em;opacity:0;filter:progid:DXImageTransform.Microsoft.Alpha(Opacity=0);}
.minimalist .fp-waiting em:nth-child(1){-webkit-animation-delay:.3s;-moz-animation-delay:.3s;animation-delay:.3s}
.minimalist .fp-waiting em:nth-child(2){-webkit-animation-delay:.45s;-moz-animation-delay:.45s;animation-delay:.45s}
.minimalist .fp-waiting em:nth-child(3){-webkit-animation-delay:.6s;-moz-animation-delay:.6s;animation-delay:.6s}
.minimalist .fp-waiting p{color:#ccc;font-weight:bold}
.minimalist .fp-speed{font-size:30px;background-color:#333;background-color:rgba(51,51,51,0.8);color:#eee;margin:0 auto;text-align:center;width:120px;padding:.1em 0 0;opacity:0;filter:progid:DXImageTransform.Microsoft.Alpha(Opacity=0);-webkit-transition:opacity .5s;-moz-transition:opacity .5s;transition:opacity .5s;}
.minimalist .fp-speed.fp-hilite{opacity:1;filter:progid:DXImageTransform.Microsoft.Alpha(Opacity=100)}
.minimalist .fp-help{position:absolute;top:0;left:-9999em;z-index:100;background-color:#333;background-color:rgba(51,51,51,0.9);width:100%;height:100%;opacity:0;filter:progid:DXImageTransform.Microsoft.Alpha(Opacity=0);-webkit-transition:opacity .2s;-moz-transition:opacity .2s;transition:opacity .2s;text-align:center;}
.is-help.minimalist .fp-help{left:0;opacity:1;filter:progid:DXImageTransform.Microsoft.Alpha(Opacity=100)}
.minimalist .fp-help .fp-help-section{margin:3%;direction:ltr}
.minimalist .fp-help .fp-help-basics{margin-top:6%}
.minimalist .fp-help p{color:#eee;margin:.5em 0;font-size:14px;line-height:1.5;display:inline-block;margin:1% 2%}
.minimalist .fp-help em{background:#eee;-webkit-border-radius:.3em;-moz-border-radius:.3em;border-radius:.3em;margin-right:.4em;padding:.3em .6em;color:#333}
.minimalist .fp-help small{font-size:90%;color:#aaa}
.minimalist .fp-help .fp-close{display:block}
@media (max-width: 600px){.minimalist .fp-help p{font-size:9px}
}.minimalist .fp-subtitle{position:absolute;bottom:40px;left:-99999em;z-index:10;text-align:center;width:100%;opacity:0;filter:progid:DXImageTransform.Microsoft.Alpha(Opacity=0);-webkit-transition:opacity .3s;-moz-transition:opacity .3s;transition:opacity .3s;}
.minimalist .fp-subtitle p{display:inline;background-color:#333;background-color:rgba(51,51,51,0.9);color:#eee;padding:.1em .4em;font-size:16px;line-height:1.6;}
.minimalist .fp-subtitle p:after{content:'';clear:both}
.minimalist .fp-subtitle.fp-active{left:0;opacity:1;filter:progid:DXImageTransform.Microsoft.Alpha(Opacity=100)}
.minimalist .fp-fullscreen,.minimalist .fp-unload,.minimalist .fp-mute,.minimalist .fp-embed,.minimalist .fp-close,.minimalist .fp-play{background-image:url(img/white.png);background-size:37px 300px;}
.is-rtl.minimalist .fp-fullscreen,.is-rtl.minimalist .fp-unload,.is-rtl.minimalist .fp-mute,.is-rtl.minimalist .fp-embed,.is-rtl.minimalist .fp-close,.is-rtl.minimalist .fp-play{background-image:url(img/white_rtl.png)}
.color-light.minimalist .fp-fullscreen,.color-light.minimalist .fp-unload,.color-light.minimalist .fp-mute,.color-light.minimalist .fp-embed,.color-light.minimalist .fp-close,.color-light.minimalist .fp-play{background-image:url(img/black.png);}
.is-rtl.color-light.minimalist .fp-fullscreen,.is-rtl.color-light.minimalist .fp-unload,.is-rtl.color-light.minimalist .fp-mute,.is-rtl.color-light.minimalist .fp-embed,.is-rtl.color-light.minimalist .fp-close,.is-rtl.color-light.minimalist .fp-play{background-image:url(img/black_rtl.png)}
@media (-webkit-min-device-pixel-ratio: 2){.color-light.minimalist .fp-fullscreen,.color-light.minimalist .fp-unload,.color-light.minimalist .fp-mute,.color-light.minimalist .fp-embed,.color-light.minimalist .fp-close,.color-light.minimalist .fp-play{background-image:url(img/black@x2.png)}
.is-rtl.color-light.minimalist .fp-fullscreen,.is-rtl.color-light.minimalist .fp-unload,.is-rtl.color-light.minimalist .fp-mute,.is-rtl.color-light.minimalist .fp-embed,.is-rtl.color-light.minimalist .fp-close,.is-rtl.color-light.minimalist .fp-play{background-image:url(img/black_rtl@x2.png)}
}@media (-webkit-min-device-pixel-ratio: 2){.minimalist .fp-fullscreen,.minimalist .fp-unload,.minimalist .fp-mute,.minimalist .fp-embed,.minimalist .fp-close,.minimalist .fp-play{background-image:url(img/white@x2.png)}
.is-rtl.minimalist .fp-fullscreen,.is-rtl.minimalist .fp-unload,.is-rtl.minimalist .fp-mute,.is-rtl.minimalist .fp-embed,.is-rtl.minimalist .fp-close,.is-rtl.minimalist .fp-play{background-image:url(img/white_rtl@x2.png)}
}.is-splash.minimalist .fp-ui,.is-paused.minimalist .fp-ui{background:url(img/play_white.png) center no-repeat;background-size:12%;}
.is-rtl.is-splash.minimalist .fp-ui,.is-rtl.is-paused.minimalist .fp-ui{background:url(img/play_white_rtl.png) center no-repeat;background-size:12%}
@media (-webkit-min-device-pixel-ratio: 2){.is-splash.minimalist .fp-ui,.is-paused.minimalist .fp-ui{background:url(img/play_white@x2.png) center no-repeat;background-size:12%}
.is-rtl.is-splash.minimalist .fp-ui,.is-rtl.is-paused.minimalist .fp-ui{background:url(img/play_white_rtl@x2.png) center no-repeat;background-size:12%}
}.color-light.is-splash.minimalist .fp-ui,.color-light.is-paused.minimalist .fp-ui{background-image:url(img/play_black.png);}
.is-rtl.color-light.is-splash.minimalist .fp-ui,.is-rtl.color-light.is-paused.minimalist .fp-ui{background-image:url(img/play_black_rtl.png)}
@media (-webkit-min-device-pixel-ratio: 2){.color-light.is-splash.minimalist .fp-ui,.color-light.is-paused.minimalist .fp-ui{background-image:url(img/play_black@x2.png);}
.is-rtl.color-light.is-splash.minimalist .fp-ui,.is-rtl.color-light.is-paused.minimalist .fp-ui{background-image:url(img/play_black_rtl@x2.png)}
}.is-fullscreen.minimalist .fp-ui{background-size:auto}
.is-seeking.minimalist .fp-ui,.is-loading.minimalist .fp-ui{background-image:none}
.minimalist .fp-logo{position:absolute;top:auto;left:15px;bottom:30px;cursor:pointer;display:none;z-index:100;}
.minimalist .fp-logo img{width:100%}
.is-embedded.minimalist .fp-logo{display:block}
.fixed-controls.minimalist .fp-logo{bottom:15px}
.minimalist .fp-fullscreen,.minimalist .fp-unload,.minimalist .fp-close{position:absolute;top:5px;left:auto;right:5px;display:block;width:30px;height:23px;background-position:12px -197px;cursor:pointer;}
.is-rtl.minimalist .fp-fullscreen,.is-rtl.minimalist .fp-unload,.is-rtl.minimalist .fp-close{right:auto;left:5px;background-position:18px -197px}
.minimalist .fp-unload,.minimalist .fp-close{background-position:14px -175px;display:none;}
.is-rtl.minimalist .fp-unload,.is-rtl.minimalist .fp-close{background-position:14px -175px}
.minimalist .fp-play{display:none;width:27px;height:20px;background-position:9px -24px;position:absolute;bottom:0;left:0;}
.is-rtl.minimalist .fp-play{background-position:18px -24px;left:auto;right:0}
.play-button.minimalist .fp-play{display:block}
.is-paused.minimalist .fp-play{background-position:9px 7px;}
.is-rtl.is-paused.minimalist .fp-play{background-position:18px 7px}
.minimalist.is-ready.is-closeable .fp-unload{display:block}
.minimalist.is-ready.is-closeable .fp-fullscreen{display:none}
.minimalist.is-fullscreen .fp-fullscreen{background-position:10px -217px;display:block !important;}
.is-rtl.minimalist.is-fullscreen .fp-fullscreen{background-position:21px -217px}
.minimalist.is-fullscreen .fp-unload,.minimalist.is-fullscreen .fp-close{display:none !important}
.minimalist .fp-timeline{height:3px;position:relative;overflow:hidden;top:5px;height:10px;margin:0 150px 0 45px;}
.no-volume.minimalist .fp-timeline{margin-right:60px}
.no-mute.minimalist .fp-timeline{margin-right:140px}
.no-mute.no-volume.minimalist .fp-timeline{margin-right:45px}
.play-button.minimalist .fp-timeline{margin-left:67px}
.is-rtl.minimalist .fp-timeline{margin:0 45px 0 150px;}
.no-volume.is-rtl.minimalist .fp-timeline{margin-left:60px}
.no-mute.is-rtl.minimalist .fp-timeline{margin-left:140px}
.no-mute.no-volume.is-rtl.minimalist .fp-timeline{margin-left:45px}
.play-button.is-rtl.minimalist .fp-timeline{margin-right:67px}
.is-long.minimalist .fp-timeline{margin:0 180px 0 75px;}
.no-volume.is-long.minimalist .fp-timeline{margin-right:90px}
.no-mute.is-long.minimalist .fp-timeline{margin-right:75px}
.play-button.is-long.minimalist .fp-timeline{margin-left:97px}
.is-rtl.is-long.minimalist .fp-timeline{margin:75px 0 180px 0;}
.no-volume.is-rtl.is-long.minimalist .fp-timeline{margin-left:90px}
.no-mute.is-rtl.is-long.minimalist .fp-timeline{margin-left:75px}
.play-button.is-rtl.is-long.minimalist .fp-timeline{margin-left:97px}
.aside-time.minimalist .fp-timeline,.no-time.minimalist .fp-timeline{margin:0 110px 0 5px}
.aside-time.no-volume.minimalist .fp-timeline,.no-time.no-volume.minimalist .fp-timeline{margin-right:20px}
.aside-time.no-mute.minimalist .fp-timeline,.no-time.no-mute.minimalist .fp-timeline{margin-right:5px}
.play-button.no-time.minimalist .fp-timeline,.play-button.aside-time.minimalist .fp-timeline{margin-left:27px}
.is-rtl.aside-time.minimalist .fp-timeline,.is-rtl.no-time.minimalist .fp-timeline{margin:0 5px 0 110px}
.is-rtl.aside-time.no-volume.minimalist .fp-timeline,.is-rtl.no-time.no-volume.minimalist .fp-timeline{margin-left:20px}
.is-rtl.aside-time.no-mute.minimalist .fp-timeline,.is-rtl.no-time.no-mute.minimalist .fp-timeline{margin-left:5px}
.is-rtl.play-button.no-time.minimalist .fp-timeline,.is-rtl.play-button.aside-time.minimalist .fp-timeline{margin-right:27px}
.minimalist .fp-buffer,.minimalist .fp-progress{position:absolute;top:0;left:auto;height:100%;cursor:col-resize}
.minimalist .fp-buffer{-webkit-transition:width .25s linear;-moz-transition:width .25s linear;transition:width .25s linear}
.minimalist.is-touch .fp-timeline{overflow:visible}
.minimalist.is-touch .fp-progress{-webkit-transition:width .2s linear;-moz-transition:width .2s linear;transition:width .2s linear}
.minimalist.is-touch .fp-timeline.is-dragging .fp-progress{-webkit-transition:right .1s linear,border .1s linear,top .1s linear,left .1s linear;-moz-transition:right .1s linear,border .1s linear,top .1s linear,left .1s linear;transition:right .1s linear,border .1s linear,top .1s linear,left .1s linear}
.minimalist.is-touch.is-mouseover .fp-progress:after,.minimalist.is-touch.is-mouseover .fp-progress:before{content:'';display:block;-webkit-border-radius:10px;-moz-border-radius:10px;border-radius:10px;position:absolute;right:-5px}
.minimalist.is-touch.is-rtl.is-mouseover .fp-progress:after,.minimalist.is-touch.is-rtl.is-mouseover .fp-progress:before{right:auto;left:-5px}
.minimalist.is-touch.is-rtl.is-mouseover .fp-progress:after{left:-10px;-webkit-box-shadow:-1px 0 4px rgba(0,0,0,0.5);-moz-box-shadow:-1px 0 4px rgba(0,0,0,0.5);box-shadow:-1px 0 4px rgba(0,0,0,0.5)}
.minimalist.is-touch.is-mouseover .fp-progress:before{width:10px;height:10px}
.minimalist.is-touch.is-mouseover .fp-progress:after{height:10px;width:10px;top:-5px;right:-10px;border:5px solid rgba(255,255,255,0.65);-webkit-box-shadow:1px 0 4px rgba(0,0,0,0.5);-moz-box-shadow:1px 0 4px rgba(0,0,0,0.5);box-shadow:1px 0 4px rgba(0,0,0,0.5)}
.minimalist.is-touch.is-mouseover .fp-timeline.is-dragging .fp-progress:after{border:10px solid #fff;-webkit-border-radius:20px;-moz-border-radius:20px;border-radius:20px;-webkit-transition:inherit;-moz-transition:inherit;transition:inherit;top:-10px;right:-15px}
.minimalist.is-touch.is-rtl.is-mouseover .fp-timeline.is-dragging .fp-progress:after{left:-15px;right:auto;border:10px solid #fff}
.minimalist .fp-volume{position:absolute;top:7.5px;right:5px;}
.is-rtl.minimalist .fp-volume{right:auto;left:5px}
.minimalist .fp-mute{position:relative;width:10px;height:15px;float:left;top:-5px;cursor:pointer;background-position:-2px -99px;}
.is-rtl.minimalist .fp-mute{float:right;background-position:-25px -99px}
.no-mute.minimalist .fp-mute{display:none}
.minimalist .fp-volumeslider{width:90px;height:5px;cursor:col-resize;float:left;}
.is-rtl.minimalist .fp-volumeslider{float:right}
.no-volume.minimalist .fp-volumeslider{display:none}
.minimalist .fp-volumelevel{height:100%}
.minimalist .fp-time{text-shadow:0 0 1px #000;font-size:12px;font-weight:bold;color:#fff;width:100%;}
.minimalist .fp-time.is-inverted .fp-duration{display:none}
.minimalist .fp-time.is-inverted .fp-remaining{display:inline}
.minimalist .fp-time em{width:35px;height:10px;line-height:10px;text-align:center;position:absolute;bottom:5px}
.no-time.minimalist .fp-time{display:none}
.is-long.minimalist .fp-time em{width:65px}
.minimalist .fp-elapsed{left:5px;}
.play-button.minimalist .fp-elapsed{left:27px}
.is-rtl.minimalist .fp-elapsed{left:auto;right:5px;}
.play-button.is-rtl.minimalist .fp-elapsed{right:27px}
.minimalist .fp-remaining,.minimalist .fp-duration{right:110px;color:#eee;}
.no-volume.minimalist .fp-remaining,.no-volume.minimalist .fp-duration{right:20px}
.no-mute.minimalist .fp-remaining,.no-mute.minimalist .fp-duration{right:100px}
.no-mute.no-volume.minimalist .fp-remaining,.no-mute.no-volume.minimalist .fp-duration{right:5px}
.is-rtl.minimalist .fp-remaining,.is-rtl.minimalist .fp-duration{right:auto;left:110px;}
.no-volume.is-rtl.minimalist .fp-remaining,.no-volume.is-rtl.minimalist .fp-duration{left:20px}
.no-mute.is-rtl.minimalist .fp-remaining,.no-mute.is-rtl.minimalist .fp-duration{left:100px}
.no-mute.no-volume.is-rtl.minimalist .fp-remaining,.no-mute.no-volume.is-rtl.minimalist .fp-duration{left:5px}
.minimalist .fp-remaining{display:none}
.minimalist.color-light .fp-time{color:#222;text-shadow:0 0 1px #fff}
.minimalist.color-light .fp-remaining,.minimalist.color-light .fp-duration{color:#666}
.minimalist.aside-time .fp-time{position:absolute;top:5px;left:5px;bottom:auto !important;width:85px;}
.minimalist.aside-time .fp-time strong,.minimalist.aside-time .fp-time em{position:static}
.minimalist.aside-time .fp-time .fp-elapsed{margin-right:5px;}
.is-rtl.minimalist.aside-time .fp-time .fp-elapsed{margin-right:auto;margin-left:5px}
.minimalist.is-long.aside-time .fp-time{width:130px}
.minimalist.is-splash,.minimalist.is-poster{cursor:pointer;}
.minimalist.is-splash .fp-controls,.minimalist.is-poster .fp-controls,.minimalist.is-splash .fp-fullscreen,.minimalist.is-poster .fp-fullscreen,.minimalist.is-splash .fp-unload,.minimalist.is-poster .fp-unload,.minimalist.is-splash .fp-time,.minimalist.is-poster .fp-time,.minimalist.is-splash .fp-embed,.minimalist.is-poster .fp-embed{display:none !important}
.minimalist.is-poster .fp-engine{top:-9999em}
.minimalist.is-loading .fp-waiting{display:block}
.minimalist.is-loading .fp-controls,.minimalist.is-loading .fp-time{display:none}
.minimalist.is-loading .fp-ui{background-position:-9999em}
.minimalist.is-seeking .fp-waiting{display:block}
.minimalist.is-fullscreen{position:fixed !important;top:0 !important;left:0 !important;border:0 !important;margin:0 !important;width:100% !important;height:100% !important;max-width:100% !important;z-index:99999 !important;-webkit-box-shadow:0 !important;-moz-box-shadow:0 !important;box-shadow:0 !important;background-image:none !important;background-color:#333;}
.is-rtl.minimalist.is-fullscreen{left:auto !important;right:0 !important}
.minimalist.is-error{border:1px solid #909090;background:#fdfdfd !important;}
.minimalist.is-error h2{font-weight:bold;font-size:large;margin-top:10%}
.minimalist.is-error .fp-message{display:block}
.minimalist.is-error object,.minimalist.is-error video,.minimalist.is-error .fp-controls,.minimalist.is-error .fp-time,.minimalist.is-error .fp-subtitle{display:none}
.minimalist.is-ready.is-muted .fp-mute{opacity:.5;filter:progid:DXImageTransform.Microsoft.Alpha(Opacity=50)}
.minimalist.is-mouseout .fp-controls{height:0;-webkit-transition:height .15s .3s;-moz-transition:height .15s .3s;transition:height .15s .3s}
.minimalist.is-mouseout .fp-timeline{margin:0 !important}
.minimalist.is-mouseout .fp-timeline{-webkit-transition:height .15s .3s,top .15s .3s,margin .15s .3s;-moz-transition:height .15s .3s,top .15s .3s,margin .15s .3s;transition:height .15s .3s,top .15s .3s,margin .15s .3s;height:4px;top:0;-webkit-border-radius:0;-moz-border-radius:0;border-radius:0}
.minimalist.is-mouseout .fp-fullscreen,.minimalist.is-mouseout .fp-unload,.minimalist.is-mouseout .fp-elapsed,.minimalist.is-mouseout .fp-remaining,.minimalist.is-mouseout .fp-duration,.minimalist.is-mouseout .fp-embed,.minimalist.is-mouseout .fp-volume,.minimalist.is-mouseout .fp-play{opacity:0;filter:progid:DXImageTransform.Microsoft.Alpha(Opacity=0);-webkit-transition:opacity .15s .3s;-moz-transition:opacity .15s .3s;transition:opacity .15s .3s}
.minimalist.is-mouseover .fp-controls,.minimalist.fixed-controls .fp-controls{height:20px}
.minimalist.is-mouseover .fp-fullscreen,.minimalist.fixed-controls .fp-fullscreen,.minimalist.is-mouseover .fp-unload,.minimalist.fixed-controls .fp-unload,.minimalist.is-mouseover .fp-elapsed,.minimalist.fixed-controls .fp-elapsed,.minimalist.is-mouseover .fp-remaining,.minimalist.fixed-controls .fp-remaining,.minimalist.is-mouseover .fp-duration,.minimalist.fixed-controls .fp-duration,.minimalist.is-mouseover .fp-embed,.minimalist.fixed-controls .fp-embed,.minimalist.is-mouseover .fp-logo,.minimalist.fixed-controls .fp-logo,.minimalist.is-mouseover .fp-volume,.minimalist.fixed-controls .fp-volume,.minimalist.is-mouseover .fp-play,.minimalist.fixed-controls .fp-play{opacity:1;filter:progid:DXImageTransform.Microsoft.Alpha(Opacity=100)}
.minimalist.fixed-controls .fp-volume{display:block}
.minimalist.fixed-controls .fp-controls{bottom:-20px;}
.is-fullscreen.minimalist.fixed-controls .fp-controls{bottom:0}
.minimalist.fixed-controls .fp-time em{bottom:-15px;opacity:1;filter:progid:DXImageTransform.Microsoft.Alpha(Opacity=100);}
.is-fullscreen.minimalist.fixed-controls .fp-time em{bottom:5px}
.minimalist.is-disabled .fp-progress{background-color:#999}
.minimalist .fp-embed{position:absolute;top:5px;left:5px;display:block;width:25px;height:20px;background-position:3px -237px;}
.is-rtl.minimalist .fp-embed{background-position:22px -237px;left:auto;right:5px}
.minimalist .fp-embed-code{position:absolute;display:none;top:10px;left:40px;background-color:#333;padding:3px 5px;-webkit-border-radius:3px;-moz-border-radius:3px;border-radius:3px;-webkit-box-shadow:0 0 3px #ccc;-moz-box-shadow:0 0 3px #ccc;box-shadow:0 0 3px #ccc;font-size:12px;}
.minimalist .fp-embed-code:before{content:'';width:0;height:0;position:absolute;top:2px;left:-10px;border:5px solid transparent;border-right-color:#333}
.is-rtl.minimalist .fp-embed-code{left:auto;right:40px;}
.is-rtl.minimalist .fp-embed-code:before{left:auto;right:-10px;border-right-color:transparent;border-left-color:#333}
.minimalist .fp-embed-code textarea{width:400px;height:16px;font-family:monaco,"courier new",verdana;color:#777;white-space:nowrap;resize:none;overflow:hidden;border:0;outline:0;background-color:transparent;color:#ccc}
.minimalist .fp-embed-code label{display:block;color:#999}
.minimalist.is-embedding .fp-embed,.minimalist.is-embedding .fp-embed-code{display:block;opacity:1;filter:progid:DXImageTransform.Microsoft.Alpha(Opacity=100)}
.minimalist.aside-time .fp-embed{left:85px;}
.is-rtl.minimalist.aside-time .fp-embed{left:auto;right:85px}
.minimalist.aside-time .fp-embed-code{left:115px;}
.is-rtl.minimalist.aside-time .fp-embed-code{left:auto;right:115px}
.minimalist.aside-time.is-embedding .fp-time{opacity:1;filter:progid:DXImageTransform.Microsoft.Alpha(Opacity=100)}
.minimalist.is-long.aside-time .fp-embed{left:130px;}
.is-rtl.minimalist.is-long.aside-time .fp-embed{left:auto;right:130px}
.minimalist.no-time .fp-embed{left:5px !important;}
.is-rtl.minimalist.no-time .fp-embed{left:auto;right:5px !important}
@-moz-keyframes pulse{0%{opacity:0}
100%{opacity:1}
}@-webkit-keyframes pulse{0%{opacity:0}
100%{opacity:1}
}@-o-keyframes pulse{0%{opacity:0}
100%{opacity:1}
}@-ms-keyframes pulse{0%{opacity:0}
100%{opacity:1}
}@keyframes pulse{0%{opacity:0}
100%{opacity:1}
}.minimalist .fp-controls{background-color:#333;background-color:rgba(51,51,51,0.6)}
.minimalist.fixed-controls .fp-controls{background-color:#333}
.minimalist .fp-timeline{background-color:#666}
.minimalist .fp-buffer{background-color:#eee}
.minimalist .fp-progress{background-color:#00a7c8}
.minimalist .fp-volumeslider{background-color:#000}
.minimalist .fp-volumelevel{background-color:#fff}
.minimalist .fp-play{height:24px}
.minimalist.is-touch.is-mouseover .fp-progress:before{background-color:#00a7c8}
.minimalist.color-light .fp-controls{background-color:rgba(255,255,255,0.6)}
.minimalist.color-light.fixed-controls .fp-controls{background-color:#fff}
.minimalist.color-light .fp-volumeslider{background-color:#ddd}
.minimalist.color-light .fp-volumelevel{background-color:#222}
.minimalist.color-alt .fp-progress{background-color:#fff}
.minimalist.color-alt.is-touch.is-mouseover .fp-progress:before{background-color:#fff}
.minimalist.color-alt .fp-buffer{background-color:#999}
.minimalist.color-alt2 .fp-progress{background-color:#900}
.minimalist.color-alt2.is-touch.is-mouseover .fp-progress:before{background-color:#900}
.functional{position:relative;width:100%;background-size:contain;background-repeat:no-repeat;background-position:center center;display:inline-block;}
.functional *{font-weight:inherit;font-family:inherit;font-style:inherit;text-decoration:inherit;font-size:100%;padding:0;border:0;margin:0;list-style-type:none}
.functional a:focus{outline:0}
.functional video{width:100%}
.functional.is-ipad video{-webkit-transform:translateX(-2048px);}
.is-ready.functional.is-ipad video{-webkit-transform:translateX(0)}
.functional .fp-engine,.functional .fp-ui,.functional .fp-message{position:absolute;top:0;left:0;width:100%;height:100%;cursor:pointer;z-index:1}
.functional .fp-message{display:none;text-align:center;padding-top:5%;cursor:default;}
.functional .fp-message h2{font-size:120%;margin-bottom:1em}
.functional .fp-message p{color:#666;font-size:95%}
.functional .fp-controls{position:absolute;bottom:0;width:100%;}
.no-background.functional .fp-controls{background-color:transparent !important;background-image:-moz-linear-gradient(transparent,transparent) !important;background-image:-webkit-gradient(linear,0 0,0 100%,from(transparent),to(transparent)) !important}
.is-fullscreen.functional .fp-controls{bottom:3px}
.is-mouseover.functional .fp-controls{bottom:0}
.functional .fp-waiting{display:none;margin:19% auto;text-align:center;}
.functional .fp-waiting *{-webkit-box-shadow:0 0 5px #333;-moz-box-shadow:0 0 5px #333;box-shadow:0 0 5px #333}
.functional .fp-waiting em{width:1em;height:1em;-webkit-border-radius:1em;-moz-border-radius:1em;border-radius:1em;background-color:rgba(255,255,255,0.8);display:inline-block;-webkit-animation:pulse .6s infinite;-moz-animation:pulse .6s infinite;animation:pulse .6s infinite;margin:.3em;opacity:0;filter:progid:DXImageTransform.Microsoft.Alpha(Opacity=0);}
.functional .fp-waiting em:nth-child(1){-webkit-animation-delay:.3s;-moz-animation-delay:.3s;animation-delay:.3s}
.functional .fp-waiting em:nth-child(2){-webkit-animation-delay:.45s;-moz-animation-delay:.45s;animation-delay:.45s}
.functional .fp-waiting em:nth-child(3){-webkit-animation-delay:.6s;-moz-animation-delay:.6s;animation-delay:.6s}
.functional .fp-waiting p{color:#ccc;font-weight:bold}
.functional .fp-speed{font-size:30px;background-color:#333;background-color:rgba(51,51,51,0.8);color:#eee;margin:0 auto;text-align:center;width:120px;padding:.1em 0 0;opacity:0;filter:progid:DXImageTransform.Microsoft.Alpha(Opacity=0);-webkit-transition:opacity .5s;-moz-transition:opacity .5s;transition:opacity .5s;}
.functional .fp-speed.fp-hilite{opacity:1;filter:progid:DXImageTransform.Microsoft.Alpha(Opacity=100)}
.functional .fp-help{position:absolute;top:0;left:-9999em;z-index:100;background-color:#333;background-color:rgba(51,51,51,0.9);width:100%;height:100%;opacity:0;filter:progid:DXImageTransform.Microsoft.Alpha(Opacity=0);-webkit-transition:opacity .2s;-moz-transition:opacity .2s;transition:opacity .2s;text-align:center;}
.is-help.functional .fp-help{left:0;opacity:1;filter:progid:DXImageTransform.Microsoft.Alpha(Opacity=100)}
.functional .fp-help .fp-help-section{margin:3%;direction:ltr}
.functional .fp-help .fp-help-basics{margin-top:6%}
.functional .fp-help p{color:#eee;margin:.5em 0;font-size:14px;line-height:1.5;display:inline-block;margin:1% 2%}
.functional .fp-help em{background:#eee;-webkit-border-radius:.3em;-moz-border-radius:.3em;border-radius:.3em;margin-right:.4em;padding:.3em .6em;color:#333}
.functional .fp-help small{font-size:90%;color:#aaa}
.functional .fp-help .fp-close{display:block}
@media (max-width: 600px){.functional .fp-help p{font-size:9px}
}.functional .fp-subtitle{position:absolute;bottom:40px;left:-99999em;z-index:10;text-align:center;width:100%;opacity:0;filter:progid:DXImageTransform.Microsoft.Alpha(Opacity=0);-webkit-transition:opacity .3s;-moz-transition:opacity .3s;transition:opacity .3s;}
.functional .fp-subtitle p{display:inline;background-color:#333;background-color:rgba(51,51,51,0.9);color:#eee;padding:.1em .4em;font-size:16px;line-height:1.6;}
.functional .fp-subtitle p:after{content:'';clear:both}
.functional .fp-subtitle.fp-active{left:0;opacity:1;filter:progid:DXImageTransform.Microsoft.Alpha(Opacity=100)}
.functional .fp-fullscreen,.functional .fp-unload,.functional .fp-mute,.functional .fp-embed,.functional .fp-close,.functional .fp-play{background-image:url(img/white.png);background-size:37px 300px;}
.is-rtl.functional .fp-fullscreen,.is-rtl.functional .fp-unload,.is-rtl.functional .fp-mute,.is-rtl.functional .fp-embed,.is-rtl.functional .fp-close,.is-rtl.functional .fp-play{background-image:url(img/white_rtl.png)}
.color-light.functional .fp-fullscreen,.color-light.functional .fp-unload,.color-light.functional .fp-mute,.color-light.functional .fp-embed,.color-light.functional .fp-close,.color-light.functional .fp-play{background-image:url(img/black.png);}
.is-rtl.color-light.functional .fp-fullscreen,.is-rtl.color-light.functional .fp-unload,.is-rtl.color-light.functional .fp-mute,.is-rtl.color-light.functional .fp-embed,.is-rtl.color-light.functional .fp-close,.is-rtl.color-light.functional .fp-play{background-image:url(img/black_rtl.png)}
@media (-webkit-min-device-pixel-ratio: 2){.color-light.functional .fp-fullscreen,.color-light.functional .fp-unload,.color-light.functional .fp-mute,.color-light.functional .fp-embed,.color-light.functional .fp-close,.color-light.functional .fp-play{background-image:url(img/black@x2.png)}
.is-rtl.color-light.functional .fp-fullscreen,.is-rtl.color-light.functional .fp-unload,.is-rtl.color-light.functional .fp-mute,.is-rtl.color-light.functional .fp-embed,.is-rtl.color-light.functional .fp-close,.is-rtl.color-light.functional .fp-play{background-image:url(img/black_rtl@x2.png)}
}@media (-webkit-min-device-pixel-ratio: 2){.functional .fp-fullscreen,.functional .fp-unload,.functional .fp-mute,.functional .fp-embed,.functional .fp-close,.functional .fp-play{background-image:url(img/white@x2.png)}
.is-rtl.functional .fp-fullscreen,.is-rtl.functional .fp-unload,.is-rtl.functional .fp-mute,.is-rtl.functional .fp-embed,.is-rtl.functional .fp-close,.is-rtl.functional .fp-play{background-image:url(img/white_rtl@x2.png)}
}.is-splash.functional .fp-ui,.is-paused.functional .fp-ui{background:url(img/play_white.png) center no-repeat;background-size:12%;}
.is-rtl.is-splash.functional .fp-ui,.is-rtl.is-paused.functional .fp-ui{background:url(img/play_white_rtl.png) center no-repeat;background-size:12%}
@media (-webkit-min-device-pixel-ratio: 2){.is-splash.functional .fp-ui,.is-paused.functional .fp-ui{background:url(img/play_white@x2.png) center no-repeat;background-size:12%}
.is-rtl.is-splash.functional .fp-ui,.is-rtl.is-paused.functional .fp-ui{background:url(img/play_white_rtl@x2.png) center no-repeat;background-size:12%}
}.color-light.is-splash.functional .fp-ui,.color-light.is-paused.functional .fp-ui{background-image:url(img/play_black.png);}
.is-rtl.color-light.is-splash.functional .fp-ui,.is-rtl.color-light.is-paused.functional .fp-ui{background-image:url(img/play_black_rtl.png)}
@media (-webkit-min-device-pixel-ratio: 2){.color-light.is-splash.functional .fp-ui,.color-light.is-paused.functional .fp-ui{background-image:url(img/play_black@x2.png);}
.is-rtl.color-light.is-splash.functional .fp-ui,.is-rtl.color-light.is-paused.functional .fp-ui{background-image:url(img/play_black_rtl@x2.png)}
}.is-fullscreen.functional .fp-ui{background-size:auto}
.is-seeking.functional .fp-ui,.is-loading.functional .fp-ui{background-image:none}
.functional .fp-logo{position:absolute;top:auto;left:15px;bottom:40px;cursor:pointer;display:none;z-index:100;}
.functional .fp-logo img{width:100%}
.is-embedded.functional .fp-logo{display:block}
.fixed-controls.functional .fp-logo{bottom:15px}
.functional .fp-fullscreen,.functional .fp-unload,.functional .fp-close{position:absolute;top:10px;left:auto;right:10px;display:block;width:30px;height:23px;background-position:12px -197px;cursor:pointer;}
.is-rtl.functional .fp-fullscreen,.is-rtl.functional .fp-unload,.is-rtl.functional .fp-close{right:auto;left:10px;background-position:18px -197px}
.functional .fp-unload,.functional .fp-close{background-position:14px -175px;display:none;}
.is-rtl.functional .fp-unload,.is-rtl.functional .fp-close{background-position:14px -175px}
.functional .fp-play{display:none;width:27px;height:30px;background-position:9px -24px;position:absolute;bottom:0;left:0;}
.is-rtl.functional .fp-play{background-position:18px -24px;left:auto;right:0}
.play-button.functional .fp-play{display:block}
.is-paused.functional .fp-play{background-position:9px 7px;}
.is-rtl.is-paused.functional .fp-play{background-position:18px 7px}
.functional.is-ready.is-closeable .fp-unload{display:block}
.functional.is-ready.is-closeable .fp-fullscreen{display:none}
.functional.is-fullscreen .fp-fullscreen{background-position:10px -217px;display:block !important;}
.is-rtl.functional.is-fullscreen .fp-fullscreen{background-position:21px -217px}
.functional.is-fullscreen .fp-unload,.functional.is-fullscreen .fp-close{display:none !important}
.functional .fp-timeline{height:3px;position:relative;overflow:hidden;top:10px;height:10px;margin:0 165px 0 55px;}
.no-volume.functional .fp-timeline{margin-right:75px}
.no-mute.functional .fp-timeline{margin-right:155px}
.no-mute.no-volume.functional .fp-timeline{margin-right:55px}
.play-button.functional .fp-timeline{margin-left:72px}
.is-rtl.functional .fp-timeline{margin:0 55px 0 165px;}
.no-volume.is-rtl.functional .fp-timeline{margin-left:75px}
.no-mute.is-rtl.functional .fp-timeline{margin-left:155px}
.no-mute.no-volume.is-rtl.functional .fp-timeline{margin-left:55px}
.play-button.is-rtl.functional .fp-timeline{margin-right:72px}
.is-long.functional .fp-timeline{margin:0 195px 0 85px;}
.no-volume.is-long.functional .fp-timeline{margin-right:105px}
.no-mute.is-long.functional .fp-timeline{margin-right:85px}
.play-button.is-long.functional .fp-timeline{margin-left:102px}
.is-rtl.is-long.functional .fp-timeline{margin:85px 0 195px 0;}
.no-volume.is-rtl.is-long.functional .fp-timeline{margin-left:105px}
.no-mute.is-rtl.is-long.functional .fp-timeline{margin-left:85px}
.play-button.is-rtl.is-long.functional .fp-timeline{margin-left:102px}
.aside-time.functional .fp-timeline,.no-time.functional .fp-timeline{margin:0 120px 0 10px}
.aside-time.no-volume.functional .fp-timeline,.no-time.no-volume.functional .fp-timeline{margin-right:30px}
.aside-time.no-mute.functional .fp-timeline,.no-time.no-mute.functional .fp-timeline{margin-right:10px}
.play-button.no-time.functional .fp-timeline,.play-button.aside-time.functional .fp-timeline{margin-left:27px}
.is-rtl.aside-time.functional .fp-timeline,.is-rtl.no-time.functional .fp-timeline{margin:0 10px 0 120px}
.is-rtl.aside-time.no-volume.functional .fp-timeline,.is-rtl.no-time.no-volume.functional .fp-timeline{margin-left:30px}
.is-rtl.aside-time.no-mute.functional .fp-timeline,.is-rtl.no-time.no-mute.functional .fp-timeline{margin-left:10px}
.is-rtl.play-button.no-time.functional .fp-timeline,.is-rtl.play-button.aside-time.functional .fp-timeline{margin-right:27px}
.functional .fp-buffer,.functional .fp-progress{position:absolute;top:0;left:auto;height:100%;cursor:col-resize}
.functional .fp-buffer{-webkit-transition:width .25s linear;-moz-transition:width .25s linear;transition:width .25s linear}
.functional.is-touch .fp-timeline{overflow:visible}
.functional.is-touch .fp-progress{-webkit-transition:width .2s linear;-moz-transition:width .2s linear;transition:width .2s linear}
.functional.is-touch .fp-timeline.is-dragging .fp-progress{-webkit-transition:right .1s linear,border .1s linear,top .1s linear,left .1s linear;-moz-transition:right .1s linear,border .1s linear,top .1s linear,left .1s linear;transition:right .1s linear,border .1s linear,top .1s linear,left .1s linear}
.functional.is-touch.is-mouseover .fp-progress:after,.functional.is-touch.is-mouseover .fp-progress:before{content:'';display:block;-webkit-border-radius:10px;-moz-border-radius:10px;border-radius:10px;position:absolute;right:-5px}
.functional.is-touch.is-rtl.is-mouseover .fp-progress:after,.functional.is-touch.is-rtl.is-mouseover .fp-progress:before{right:auto;left:-5px}
.functional.is-touch.is-rtl.is-mouseover .fp-progress:after{left:-10px;-webkit-box-shadow:-1px 0 4px rgba(0,0,0,0.5);-moz-box-shadow:-1px 0 4px rgba(0,0,0,0.5);box-shadow:-1px 0 4px rgba(0,0,0,0.5)}
.functional.is-touch.is-mouseover .fp-progress:before{width:10px;height:10px}
.functional.is-touch.is-mouseover .fp-progress:after{height:10px;width:10px;top:-5px;right:-10px;border:5px solid rgba(255,255,255,0.65);-webkit-box-shadow:1px 0 4px rgba(0,0,0,0.5);-moz-box-shadow:1px 0 4px rgba(0,0,0,0.5);box-shadow:1px 0 4px rgba(0,0,0,0.5)}
.functional.is-touch.is-mouseover .fp-timeline.is-dragging .fp-progress:after{border:10px solid #fff;-webkit-border-radius:20px;-moz-border-radius:20px;border-radius:20px;-webkit-transition:inherit;-moz-transition:inherit;transition:inherit;top:-10px;right:-15px}
.functional.is-touch.is-rtl.is-mouseover .fp-timeline.is-dragging .fp-progress:after{left:-15px;right:auto;border:10px solid #fff}
.functional .fp-volume{position:absolute;top:11px;right:10px;}
.is-rtl.functional .fp-volume{right:auto;left:10px}
.functional .fp-mute{position:relative;width:10px;height:15px;float:left;top:-3.5px;cursor:pointer;background-position:-2px -99px;}
.is-rtl.functional .fp-mute{float:right;background-position:-25px -99px}
.no-mute.functional .fp-mute{display:none}
.functional .fp-volumeslider{width:90px;height:8px;cursor:col-resize;float:left;}
.is-rtl.functional .fp-volumeslider{float:right}
.no-volume.functional .fp-volumeslider{display:none}
.functional .fp-volumelevel{height:100%}
.functional .fp-time{text-shadow:0 0 1px #000;font-size:12px;font-weight:bold;color:#fff;width:100%;}
.functional .fp-time.is-inverted .fp-duration{display:none}
.functional .fp-time.is-inverted .fp-remaining{display:inline}
.functional .fp-time em{width:35px;height:10px;line-height:10px;text-align:center;position:absolute;bottom:10px}
.no-time.functional .fp-time{display:none}
.is-long.functional .fp-time em{width:65px}
.functional .fp-elapsed{left:10px;}
.play-button.functional .fp-elapsed{left:27px}
.is-rtl.functional .fp-elapsed{left:auto;right:10px;}
.play-button.is-rtl.functional .fp-elapsed{right:27px}
.functional .fp-remaining,.functional .fp-duration{right:120px;color:#eee;}
.no-volume.functional .fp-remaining,.no-volume.functional .fp-duration{right:30px}
.no-mute.functional .fp-remaining,.no-mute.functional .fp-duration{right:110px}
.no-mute.no-volume.functional .fp-remaining,.no-mute.no-volume.functional .fp-duration{right:10px}
.is-rtl.functional .fp-remaining,.is-rtl.functional .fp-duration{right:auto;left:120px;}
.no-volume.is-rtl.functional .fp-remaining,.no-volume.is-rtl.functional .fp-duration{left:30px}
.no-mute.is-rtl.functional .fp-remaining,.no-mute.is-rtl.functional .fp-duration{left:110px}
.no-mute.no-volume.is-rtl.functional .fp-remaining,.no-mute.no-volume.is-rtl.functional .fp-duration{left:10px}
.functional .fp-remaining{display:none}
.functional.color-light .fp-time{color:#222;text-shadow:0 0 1px #fff}
.functional.color-light .fp-remaining,.functional.color-light .fp-duration{color:#666}
.functional.aside-time .fp-time{position:absolute;top:10px;left:10px;bottom:auto !important;width:100px;}
.functional.aside-time .fp-time strong,.functional.aside-time .fp-time em{position:static}
.functional.aside-time .fp-time .fp-elapsed{margin-right:10px;}
.is-rtl.functional.aside-time .fp-time .fp-elapsed{margin-right:auto;margin-left:10px}
.functional.is-long.aside-time .fp-time{width:130px}
.functional.is-splash,.functional.is-poster{cursor:pointer;}
.functional.is-splash .fp-controls,.functional.is-poster .fp-controls,.functional.is-splash .fp-fullscreen,.functional.is-poster .fp-fullscreen,.functional.is-splash .fp-unload,.functional.is-poster .fp-unload,.functional.is-splash .fp-time,.functional.is-poster .fp-time,.functional.is-splash .fp-embed,.functional.is-poster .fp-embed{display:none !important}
.functional.is-poster .fp-engine{top:-9999em}
.functional.is-loading .fp-waiting{display:block}
.functional.is-loading .fp-controls,.functional.is-loading .fp-time{display:none}
.functional.is-loading .fp-ui{background-position:-9999em}
.functional.is-seeking .fp-waiting{display:block}
.functional.is-fullscreen{position:fixed !important;top:0 !important;left:0 !important;border:0 !important;margin:0 !important;width:100% !important;height:100% !important;max-width:100% !important;z-index:99999 !important;-webkit-box-shadow:0 !important;-moz-box-shadow:0 !important;box-shadow:0 !important;background-image:none !important;background-color:#333;}
.is-rtl.functional.is-fullscreen{left:auto !important;right:0 !important}
.functional.is-error{border:1px solid #909090;background:#fdfdfd !important;}
.functional.is-error h2{font-weight:bold;font-size:large;margin-top:10%}
.functional.is-error .fp-message{display:block}
.functional.is-error object,.functional.is-error video,.functional.is-error .fp-controls,.functional.is-error .fp-time,.functional.is-error .fp-subtitle{display:none}
.functional.is-ready.is-muted .fp-mute{opacity:.5;filter:progid:DXImageTransform.Microsoft.Alpha(Opacity=50)}
.functional.is-mouseout .fp-controls{height:0;-webkit-transition:height .15s .3s;-moz-transition:height .15s .3s;transition:height .15s .3s}
.functional.is-mouseout .fp-timeline{margin:0 !important}
.functional.is-mouseout .fp-timeline{-webkit-transition:height .15s .3s,top .15s .3s,margin .15s .3s;-moz-transition:height .15s .3s,top .15s .3s,margin .15s .3s;transition:height .15s .3s,top .15s .3s,margin .15s .3s;height:4px;top:0;-webkit-border-radius:0;-moz-border-radius:0;border-radius:0}
.functional.is-mouseout .fp-fullscreen,.functional.is-mouseout .fp-unload,.functional.is-mouseout .fp-elapsed,.functional.is-mouseout .fp-remaining,.functional.is-mouseout .fp-duration,.functional.is-mouseout .fp-embed,.functional.is-mouseout .fp-volume,.functional.is-mouseout .fp-play{opacity:0;filter:progid:DXImageTransform.Microsoft.Alpha(Opacity=0);-webkit-transition:opacity .15s .3s;-moz-transition:opacity .15s .3s;transition:opacity .15s .3s}
.functional.is-mouseover .fp-controls,.functional.fixed-controls .fp-controls{height:30px}
.functional.is-mouseover .fp-fullscreen,.functional.fixed-controls .fp-fullscreen,.functional.is-mouseover .fp-unload,.functional.fixed-controls .fp-unload,.functional.is-mouseover .fp-elapsed,.functional.fixed-controls .fp-elapsed,.functional.is-mouseover .fp-remaining,.functional.fixed-controls .fp-remaining,.functional.is-mouseover .fp-duration,.functional.fixed-controls .fp-duration,.functional.is-mouseover .fp-embed,.functional.fixed-controls .fp-embed,.functional.is-mouseover .fp-logo,.functional.fixed-controls .fp-logo,.functional.is-mouseover .fp-volume,.functional.fixed-controls .fp-volume,.functional.is-mouseover .fp-play,.functional.fixed-controls .fp-play{opacity:1;filter:progid:DXImageTransform.Microsoft.Alpha(Opacity=100)}
.functional.fixed-controls .fp-volume{display:block}
.functional.fixed-controls .fp-controls{bottom:-30px;}
.is-fullscreen.functional.fixed-controls .fp-controls{bottom:0}
.functional.fixed-controls .fp-time em{bottom:-20px;opacity:1;filter:progid:DXImageTransform.Microsoft.Alpha(Opacity=100);}
.is-fullscreen.functional.fixed-controls .fp-time em{bottom:10px}
.functional.is-disabled .fp-progress{background-color:#999}
.functional .fp-embed{position:absolute;top:10px;left:10px;display:block;width:25px;height:20px;background-position:3px -237px;}
.is-rtl.functional .fp-embed{background-position:22px -237px;left:auto;right:10px}
.functional .fp-embed-code{position:absolute;display:none;top:10px;left:40px;background-color:#333;padding:3px 5px;-webkit-border-radius:3px;-moz-border-radius:3px;border-radius:3px;-webkit-box-shadow:0 0 3px #ccc;-moz-box-shadow:0 0 3px #ccc;box-shadow:0 0 3px #ccc;font-size:12px;}
.functional .fp-embed-code:before{content:'';width:0;height:0;position:absolute;top:2px;left:-10px;border:5px solid transparent;border-right-color:#333}
.is-rtl.functional .fp-embed-code{left:auto;right:40px;}
.is-rtl.functional .fp-embed-code:before{left:auto;right:-10px;border-right-color:transparent;border-left-color:#333}
.functional .fp-embed-code textarea{width:400px;height:16px;font-family:monaco,"courier new",verdana;color:#777;white-space:nowrap;resize:none;overflow:hidden;border:0;outline:0;background-color:transparent;color:#ccc}
.functional .fp-embed-code label{display:block;color:#999}
.functional.is-embedding .fp-embed,.functional.is-embedding .fp-embed-code{display:block;opacity:1;filter:progid:DXImageTransform.Microsoft.Alpha(Opacity=100)}
.functional.aside-time .fp-embed{left:100px;}
.is-rtl.functional.aside-time .fp-embed{left:auto;right:100px}
.functional.aside-time .fp-embed-code{left:130px;}
.is-rtl.functional.aside-time .fp-embed-code{left:auto;right:130px}
.functional.aside-time.is-embedding .fp-time{opacity:1;filter:progid:DXImageTransform.Microsoft.Alpha(Opacity=100)}
.functional.is-long.aside-time .fp-embed{left:130px;}
.is-rtl.functional.is-long.aside-time .fp-embed{left:auto;right:130px}
.functional.no-time .fp-embed{left:10px !important;}
.is-rtl.functional.no-time .fp-embed{left:auto;right:10px !important}
@-moz-keyframes pulse{0%{opacity:0}
100%{opacity:1}
}@-webkit-keyframes pulse{0%{opacity:0}
100%{opacity:1}
}@-o-keyframes pulse{0%{opacity:0}
100%{opacity:1}
}@-ms-keyframes pulse{0%{opacity:0}
100%{opacity:1}
}@keyframes pulse{0%{opacity:0}
100%{opacity:1}
}.functional .fp-controls{background-color:#111}
.functional .fp-timeline{background-color:#555}
.functional .fp-buffer{background-color:#eee}
.functional .fp-progress{background-color:#4da5d8}
.functional.is-touch.is-mouseover .fp-progress:before{background-color:#4da5d8}
.functional .fp-volumelevel{background-color:#fff}
.functional .fp-volumeslider{background-color:#555}
.functional .fp-timeline,.functional .fp-volumeslider{border:1px inset;border-color:rgba(0,0,0,0.2) rgba(17,17,17,0.05)}
.functional .fp-controls,.functional .fp-progress{background-image:-moz-linear-gradient(rgba(255,255,255,0.4),rgba(255,255,255,0.01));background-image:-webkit-gradient(linear,0 0,0 100%,from(rgba(255,255,255,0.4)),to(rgba(255,255,255,0.01)))}
.functional .fp-timeline,.functional .fp-buffer,.functional .fp-progress,.functional .fp-volumeslider,.functional .fp-volumelevel{-webkit-border-radius:10px;-moz-border-radius:10px;border-radius:10px}
.functional.color-light .fp-controls{background-color:#eee;background-image:-moz-linear-gradient(rgba(0,0,0,0.01),rgba(0,0,0,0.3));background-image:-webkit-gradient(linear,0 0,0 100%,from(rgba(0,0,0,0.01)),to(rgba(0,0,0,0.3)))}
.functional.color-light .fp-timeline,.functional.color-light .fp-volumeslider{border-color:#eee #ccc}
.functional.color-light .fp-timeline,.functional.color-light .fp-volumeslider{background-color:#ccc;font-size:10px}
.functional.color-alt .fp-progress{background-image:-moz-linear-gradient(#999,#111);background-image:-webkit-gradient(linear,0 0,0 100%,from(#999),to(#111))}
.functional.color-alt.is-touch.is-mouseover .fp-progress:before{background-image:-moz-linear-gradient(#999,#111);background-image:-webkit-gradient(linear,0 0,0 100%,from(#999),to(#111))}
.functional.color-alt .fp-timeline,.functional.color-alt .fp-volumeslider{background-color:#111}
.functional.color-alt2 .fp-progress{background-color:#900}
.functional.color-alt2.is-touch.is-mouseover .fp-progress:before{background-color:#900}
.playful{position:relative;width:100%;background-size:contain;background-repeat:no-repeat;background-position:center center;display:inline-block;}
.playful *{font-weight:inherit;font-family:inherit;font-style:inherit;text-decoration:inherit;font-size:100%;padding:0;border:0;margin:0;list-style-type:none}
.playful a:focus{outline:0}
.playful video{width:100%}
.playful.is-ipad video{-webkit-transform:translateX(-2048px);}
.is-ready.playful.is-ipad video{-webkit-transform:translateX(0)}
.playful .fp-engine,.playful .fp-ui,.playful .fp-message{position:absolute;top:0;left:0;width:100%;height:100%;cursor:pointer;z-index:1}
.playful .fp-message{display:none;text-align:center;padding-top:5%;cursor:default;}
.playful .fp-message h2{font-size:120%;margin-bottom:1em}
.playful .fp-message p{color:#666;font-size:95%}
.playful .fp-controls{position:absolute;bottom:0;width:100%;}
.no-background.playful .fp-controls{background-color:transparent !important;background-image:-moz-linear-gradient(transparent,transparent) !important;background-image:-webkit-gradient(linear,0 0,0 100%,from(transparent),to(transparent)) !important}
.is-fullscreen.playful .fp-controls{bottom:3px}
.is-mouseover.playful .fp-controls{bottom:0}
.playful .fp-waiting{display:none;margin:19% auto;text-align:center;}
.playful .fp-waiting *{-webkit-box-shadow:0 0 5px #333;-moz-box-shadow:0 0 5px #333;box-shadow:0 0 5px #333}
.playful .fp-waiting em{width:1em;height:1em;-webkit-border-radius:1em;-moz-border-radius:1em;border-radius:1em;background-color:rgba(255,255,255,0.8);display:inline-block;-webkit-animation:pulse .6s infinite;-moz-animation:pulse .6s infinite;animation:pulse .6s infinite;margin:.3em;opacity:0;filter:progid:DXImageTransform.Microsoft.Alpha(Opacity=0);}
.playful .fp-waiting em:nth-child(1){-webkit-animation-delay:.3s;-moz-animation-delay:.3s;animation-delay:.3s}
.playful .fp-waiting em:nth-child(2){-webkit-animation-delay:.45s;-moz-animation-delay:.45s;animation-delay:.45s}
.playful .fp-waiting em:nth-child(3){-webkit-animation-delay:.6s;-moz-animation-delay:.6s;animation-delay:.6s}
.playful .fp-waiting p{color:#ccc;font-weight:bold}
.playful .fp-speed{font-size:30px;background-color:#333;background-color:rgba(51,51,51,0.8);color:#eee;margin:0 auto;text-align:center;width:120px;padding:.1em 0 0;opacity:0;filter:progid:DXImageTransform.Microsoft.Alpha(Opacity=0);-webkit-transition:opacity .5s;-moz-transition:opacity .5s;transition:opacity .5s;}
.playful .fp-speed.fp-hilite{opacity:1;filter:progid:DXImageTransform.Microsoft.Alpha(Opacity=100)}
.playful .fp-help{position:absolute;top:0;left:-9999em;z-index:100;background-color:#333;background-color:rgba(51,51,51,0.9);width:100%;height:100%;opacity:0;filter:progid:DXImageTransform.Microsoft.Alpha(Opacity=0);-webkit-transition:opacity .2s;-moz-transition:opacity .2s;transition:opacity .2s;text-align:center;}
.is-help.playful .fp-help{left:0;opacity:1;filter:progid:DXImageTransform.Microsoft.Alpha(Opacity=100)}
.playful .fp-help .fp-help-section{margin:3%;direction:ltr}
.playful .fp-help .fp-help-basics{margin-top:6%}
.playful .fp-help p{color:#eee;margin:.5em 0;font-size:14px;line-height:1.5;display:inline-block;margin:1% 2%}
.playful .fp-help em{background:#eee;-webkit-border-radius:.3em;-moz-border-radius:.3em;border-radius:.3em;margin-right:.4em;padding:.3em .6em;color:#333}
.playful .fp-help small{font-size:90%;color:#aaa}
.playful .fp-help .fp-close{display:block}
@media (max-width: 600px){.playful .fp-help p{font-size:9px}
}.playful .fp-subtitle{position:absolute;bottom:40px;left:-99999em;z-index:10;text-align:center;width:100%;opacity:0;filter:progid:DXImageTransform.Microsoft.Alpha(Opacity=0);-webkit-transition:opacity .3s;-moz-transition:opacity .3s;transition:opacity .3s;}
.playful .fp-subtitle p{display:inline;background-color:#333;background-color:rgba(51,51,51,0.9);color:#eee;padding:.1em .4em;font-size:16px;line-height:1.6;}
.playful .fp-subtitle p:after{content:'';clear:both}
.playful .fp-subtitle.fp-active{left:0;opacity:1;filter:progid:DXImageTransform.Microsoft.Alpha(Opacity=100)}
.playful .fp-fullscreen,.playful .fp-unload,.playful .fp-mute,.playful .fp-embed,.playful .fp-close,.playful .fp-play{background-image:url(img/playful_white.png);background-size:37px 300px;}
.is-rtl.playful .fp-fullscreen,.is-rtl.playful .fp-unload,.is-rtl.playful .fp-mute,.is-rtl.playful .fp-embed,.is-rtl.playful .fp-close,.is-rtl.playful .fp-play{background-image:url(img/playful_white_rtl.png)}
.color-light.playful .fp-fullscreen,.color-light.playful .fp-unload,.color-light.playful .fp-mute,.color-light.playful .fp-embed,.color-light.playful .fp-close,.color-light.playful .fp-play{background-image:url(img/playful_black.png);}
.is-rtl.color-light.playful .fp-fullscreen,.is-rtl.color-light.playful .fp-unload,.is-rtl.color-light.playful .fp-mute,.is-rtl.color-light.playful .fp-embed,.is-rtl.color-light.playful .fp-close,.is-rtl.color-light.playful .fp-play{background-image:url(img/playful_black_rtl.png)}
@media (-webkit-min-device-pixel-ratio: 2){.color-light.playful .fp-fullscreen,.color-light.playful .fp-unload,.color-light.playful .fp-mute,.color-light.playful .fp-embed,.color-light.playful .fp-close,.color-light.playful .fp-play{background-image:url(img/playful_black@x2.png)}
.is-rtl.color-light.playful .fp-fullscreen,.is-rtl.color-light.playful .fp-unload,.is-rtl.color-light.playful .fp-mute,.is-rtl.color-light.playful .fp-embed,.is-rtl.color-light.playful .fp-close,.is-rtl.color-light.playful .fp-play{background-image:url(img/playful_black_rtl@x2.png)}
}@media (-webkit-min-device-pixel-ratio: 2){.playful .fp-fullscreen,.playful .fp-unload,.playful .fp-mute,.playful .fp-embed,.playful .fp-close,.playful .fp-play{background-image:url(img/playful_white@x2.png)}
.is-rtl.playful .fp-fullscreen,.is-rtl.playful .fp-unload,.is-rtl.playful .fp-mute,.is-rtl.playful .fp-embed,.is-rtl.playful .fp-close,.is-rtl.playful .fp-play{background-image:url(img/playful_white_rtl@x2.png)}
}.is-splash.playful .fp-ui,.is-paused.playful .fp-ui{background:url(img/play_white.png) center no-repeat;background-size:12%;}
.is-rtl.is-splash.playful .fp-ui,.is-rtl.is-paused.playful .fp-ui{background:url(img/play_white_rtl.png) center no-repeat;background-size:12%}
@media (-webkit-min-device-pixel-ratio: 2){.is-splash.playful .fp-ui,.is-paused.playful .fp-ui{background:url(img/play_white@x2.png) center no-repeat;background-size:12%}
.is-rtl.is-splash.playful .fp-ui,.is-rtl.is-paused.playful .fp-ui{background:url(img/play_white_rtl@x2.png) center no-repeat;background-size:12%}
}.color-light.is-splash.playful .fp-ui,.color-light.is-paused.playful .fp-ui{background-image:url(img/play_black.png);}
.is-rtl.color-light.is-splash.playful .fp-ui,.is-rtl.color-light.is-paused.playful .fp-ui{background-image:url(img/play_black_rtl.png)}
@media (-webkit-min-device-pixel-ratio: 2){.color-light.is-splash.playful .fp-ui,.color-light.is-paused.playful .fp-ui{background-image:url(img/play_black@x2.png);}
.is-rtl.color-light.is-splash.playful .fp-ui,.is-rtl.color-light.is-paused.playful .fp-ui{background-image:url(img/play_black_rtl@x2.png)}
}.is-fullscreen.playful .fp-ui{background-size:auto}
.is-seeking.playful .fp-ui,.is-loading.playful .fp-ui{background-image:none}
.playful .fp-logo{position:absolute;top:auto;left:15px;bottom:45px;cursor:pointer;display:none;z-index:100;}
.playful .fp-logo img{width:100%}
.is-embedded.playful .fp-logo{display:block}
.fixed-controls.playful .fp-logo{bottom:15px}
.playful .fp-fullscreen,.playful .fp-unload,.playful .fp-close{position:absolute;top:12px;left:auto;right:12px;display:block;width:30px;height:23px;background-position:12px -197px;cursor:pointer;}
.is-rtl.playful .fp-fullscreen,.is-rtl.playful .fp-unload,.is-rtl.playful .fp-close{right:auto;left:12px;background-position:18px -197px}
.playful .fp-unload,.playful .fp-close{background-position:14px -175px;display:none;}
.is-rtl.playful .fp-unload,.is-rtl.playful .fp-close{background-position:14px -175px}
.playful .fp-play{display:none;width:27px;height:35px;background-position:9px -24px;position:absolute;bottom:0;left:0;}
.is-rtl.playful .fp-play{background-position:18px -24px;left:auto;right:0}
.play-button.playful .fp-play{display:block}
.is-paused.playful .fp-play{background-position:9px 7px;}
.is-rtl.is-paused.playful .fp-play{background-position:18px 7px}
.playful.is-ready.is-closeable .fp-unload{display:block}
.playful.is-ready.is-closeable .fp-fullscreen{display:none}
.playful.is-fullscreen .fp-fullscreen{background-position:10px -217px;display:block !important;}
.is-rtl.playful.is-fullscreen .fp-fullscreen{background-position:21px -217px}
.playful.is-fullscreen .fp-unload,.playful.is-fullscreen .fp-close{display:none !important}
.playful .fp-timeline{height:3px;position:relative;overflow:hidden;top:12px;height:11px;margin:0 199px 0 59px;}
.no-volume.playful .fp-timeline{margin-right:109px}
.no-mute.playful .fp-timeline{margin-right:161px}
.no-mute.no-volume.playful .fp-timeline{margin-right:59px}
.play-button.playful .fp-timeline{margin-left:74px}
.is-rtl.playful .fp-timeline{margin:0 59px 0 199px;}
.no-volume.is-rtl.playful .fp-timeline{margin-left:109px}
.no-mute.is-rtl.playful .fp-timeline{margin-left:161px}
.no-mute.no-volume.is-rtl.playful .fp-timeline{margin-left:59px}
.play-button.is-rtl.playful .fp-timeline{margin-right:74px}
.is-long.playful .fp-timeline{margin:0 229px 0 89px;}
.no-volume.is-long.playful .fp-timeline{margin-right:139px}
.no-mute.is-long.playful .fp-timeline{margin-right:89px}
.play-button.is-long.playful .fp-timeline{margin-left:104px}
.is-rtl.is-long.playful .fp-timeline{margin:89px 0 229px 0;}
.no-volume.is-rtl.is-long.playful .fp-timeline{margin-left:139px}
.no-mute.is-rtl.is-long.playful .fp-timeline{margin-left:89px}
.play-button.is-rtl.is-long.playful .fp-timeline{margin-left:104px}
.aside-time.playful .fp-timeline,.no-time.playful .fp-timeline{margin:0 152px 0 12px}
.aside-time.no-volume.playful .fp-timeline,.no-time.no-volume.playful .fp-timeline{margin-right:62px}
.aside-time.no-mute.playful .fp-timeline,.no-time.no-mute.playful .fp-timeline{margin-right:12px}
.play-button.no-time.playful .fp-timeline,.play-button.aside-time.playful .fp-timeline{margin-left:27px}
.is-rtl.aside-time.playful .fp-timeline,.is-rtl.no-time.playful .fp-timeline{margin:0 12px 0 152px}
.is-rtl.aside-time.no-volume.playful .fp-timeline,.is-rtl.no-time.no-volume.playful .fp-timeline{margin-left:62px}
.is-rtl.aside-time.no-mute.playful .fp-timeline,.is-rtl.no-time.no-mute.playful .fp-timeline{margin-left:12px}
.is-rtl.play-button.no-time.playful .fp-timeline,.is-rtl.play-button.aside-time.playful .fp-timeline{margin-right:27px}
.playful .fp-buffer,.playful .fp-progress{position:absolute;top:0;left:auto;height:100%;cursor:col-resize}
.playful .fp-buffer{-webkit-transition:width .25s linear;-moz-transition:width .25s linear;transition:width .25s linear}
.playful.is-touch .fp-timeline{overflow:visible}
.playful.is-touch .fp-progress{-webkit-transition:width .2s linear;-moz-transition:width .2s linear;transition:width .2s linear}
.playful.is-touch .fp-timeline.is-dragging .fp-progress{-webkit-transition:right .1s linear,border .1s linear,top .1s linear,left .1s linear;-moz-transition:right .1s linear,border .1s linear,top .1s linear,left .1s linear;transition:right .1s linear,border .1s linear,top .1s linear,left .1s linear}
.playful.is-touch.is-mouseover .fp-progress:after,.playful.is-touch.is-mouseover .fp-progress:before{content:'';display:block;-webkit-border-radius:10px;-moz-border-radius:10px;border-radius:10px;position:absolute;right:-5px}
.playful.is-touch.is-rtl.is-mouseover .fp-progress:after,.playful.is-touch.is-rtl.is-mouseover .fp-progress:before{right:auto;left:-5px}
.playful.is-touch.is-rtl.is-mouseover .fp-progress:after{left:-10px;-webkit-box-shadow:-1px 0 4px rgba(0,0,0,0.5);-moz-box-shadow:-1px 0 4px rgba(0,0,0,0.5);box-shadow:-1px 0 4px rgba(0,0,0,0.5)}
.playful.is-touch.is-mouseover .fp-progress:before{width:10px;height:10px}
.playful.is-touch.is-mouseover .fp-progress:after{height:10px;width:10px;top:-5px;right:-10px;border:5px solid rgba(255,255,255,0.65);-webkit-box-shadow:1px 0 4px rgba(0,0,0,0.5);-moz-box-shadow:1px 0 4px rgba(0,0,0,0.5);box-shadow:1px 0 4px rgba(0,0,0,0.5)}
.playful.is-touch.is-mouseover .fp-timeline.is-dragging .fp-progress:after{border:10px solid #fff;-webkit-border-radius:20px;-moz-border-radius:20px;border-radius:20px;-webkit-transition:inherit;-moz-transition:inherit;transition:inherit;top:-10px;right:-15px}
.playful.is-touch.is-rtl.is-mouseover .fp-timeline.is-dragging .fp-progress:after{left:-15px;right:auto;border:10px solid #fff}
.playful .fp-volume{position:absolute;top:12px;right:12px;}
.is-rtl.playful .fp-volume{right:auto;left:12px}
.playful .fp-mute{position:relative;width:38px;height:20px;float:left;top:-4.5px;cursor:pointer;background-position:-2px -99px;}
.is-rtl.playful .fp-mute{float:right;background-position:-25px -99px}
.no-mute.playful .fp-mute{display:none}
.playful .fp-volumeslider{width:90px;height:11px;cursor:col-resize;float:left;}
.is-rtl.playful .fp-volumeslider{float:right}
.no-volume.playful .fp-volumeslider{display:none}
.playful .fp-volumelevel{height:100%}
.playful .fp-time{text-shadow:0 0 1px #000;font-size:12px;font-weight:bold;color:#fff;width:100%;}
.playful .fp-time.is-inverted .fp-duration{display:none}
.playful .fp-time.is-inverted .fp-remaining{display:inline}
.playful .fp-time em{width:35px;height:11px;line-height:11px;text-align:center;position:absolute;bottom:12px}
.no-time.playful .fp-time{display:none}
.is-long.playful .fp-time em{width:65px}
.playful .fp-elapsed{left:12px;}
.play-button.playful .fp-elapsed{left:27px}
.is-rtl.playful .fp-elapsed{left:auto;right:12px;}
.play-button.is-rtl.playful .fp-elapsed{right:27px}
.playful .fp-remaining,.playful .fp-duration{right:152px;color:#eee;}
.no-volume.playful .fp-remaining,.no-volume.playful .fp-duration{right:62px}
.no-mute.playful .fp-remaining,.no-mute.playful .fp-duration{right:114px}
.no-mute.no-volume.playful .fp-remaining,.no-mute.no-volume.playful .fp-duration{right:12px}
.is-rtl.playful .fp-remaining,.is-rtl.playful .fp-duration{right:auto;left:152px;}
.no-volume.is-rtl.playful .fp-remaining,.no-volume.is-rtl.playful .fp-duration{left:62px}
.no-mute.is-rtl.playful .fp-remaining,.no-mute.is-rtl.playful .fp-duration{left:114px}
.no-mute.no-volume.is-rtl.playful .fp-remaining,.no-mute.no-volume.is-rtl.playful .fp-duration{left:12px}
.playful .fp-remaining{display:none}
.playful.color-light .fp-time{color:#222;text-shadow:0 0 1px #fff}
.playful.color-light .fp-remaining,.playful.color-light .fp-duration{color:#666}
.playful.aside-time .fp-time{position:absolute;top:12px;left:12px;bottom:auto !important;width:110px;}
.playful.aside-time .fp-time strong,.playful.aside-time .fp-time em{position:static}
.playful.aside-time .fp-time .fp-elapsed{margin-right:12px;}
.is-rtl.playful.aside-time .fp-time .fp-elapsed{margin-right:auto;margin-left:12px}
.playful.is-long.aside-time .fp-time{width:130px}
.playful.is-splash,.playful.is-poster{cursor:pointer;}
.playful.is-splash .fp-controls,.playful.is-poster .fp-controls,.playful.is-splash .fp-fullscreen,.playful.is-poster .fp-fullscreen,.playful.is-splash .fp-unload,.playful.is-poster .fp-unload,.playful.is-splash .fp-time,.playful.is-poster .fp-time,.playful.is-splash .fp-embed,.playful.is-poster .fp-embed{display:none !important}
.playful.is-poster .fp-engine{top:-9999em}
.playful.is-loading .fp-waiting{display:block}
.playful.is-loading .fp-controls,.playful.is-loading .fp-time{display:none}
.playful.is-loading .fp-ui{background-position:-9999em}
.playful.is-seeking .fp-waiting{display:block}
.playful.is-fullscreen{position:fixed !important;top:0 !important;left:0 !important;border:0 !important;margin:0 !important;width:100% !important;height:100% !important;max-width:100% !important;z-index:99999 !important;-webkit-box-shadow:0 !important;-moz-box-shadow:0 !important;box-shadow:0 !important;background-image:none !important;background-color:#333;}
.is-rtl.playful.is-fullscreen{left:auto !important;right:0 !important}
.playful.is-error{border:1px solid #909090;background:#fdfdfd !important;}
.playful.is-error h2{font-weight:bold;font-size:large;margin-top:10%}
.playful.is-error .fp-message{display:block}
.playful.is-error object,.playful.is-error video,.playful.is-error .fp-controls,.playful.is-error .fp-time,.playful.is-error .fp-subtitle{display:none}
.playful.is-ready.is-muted .fp-mute{opacity:.5;filter:progid:DXImageTransform.Microsoft.Alpha(Opacity=50)}
.playful.is-mouseout .fp-controls{height:0;-webkit-transition:height .15s .3s;-moz-transition:height .15s .3s;transition:height .15s .3s}
.playful.is-mouseout .fp-timeline{margin:0 !important}
.playful.is-mouseout .fp-timeline{-webkit-transition:height .15s .3s,top .15s .3s,margin .15s .3s;-moz-transition:height .15s .3s,top .15s .3s,margin .15s .3s;transition:height .15s .3s,top .15s .3s,margin .15s .3s;height:4px;top:0;-webkit-border-radius:0;-moz-border-radius:0;border-radius:0}
.playful.is-mouseout .fp-fullscreen,.playful.is-mouseout .fp-unload,.playful.is-mouseout .fp-elapsed,.playful.is-mouseout .fp-remaining,.playful.is-mouseout .fp-duration,.playful.is-mouseout .fp-embed,.playful.is-mouseout .fp-volume,.playful.is-mouseout .fp-play{opacity:0;filter:progid:DXImageTransform.Microsoft.Alpha(Opacity=0);-webkit-transition:opacity .15s .3s;-moz-transition:opacity .15s .3s;transition:opacity .15s .3s}
.playful.is-mouseover .fp-controls,.playful.fixed-controls .fp-controls{height:35px}
.playful.is-mouseover .fp-fullscreen,.playful.fixed-controls .fp-fullscreen,.playful.is-mouseover .fp-unload,.playful.fixed-controls .fp-unload,.playful.is-mouseover .fp-elapsed,.playful.fixed-controls .fp-elapsed,.playful.is-mouseover .fp-remaining,.playful.fixed-controls .fp-remaining,.playful.is-mouseover .fp-duration,.playful.fixed-controls .fp-duration,.playful.is-mouseover .fp-embed,.playful.fixed-controls .fp-embed,.playful.is-mouseover .fp-logo,.playful.fixed-controls .fp-logo,.playful.is-mouseover .fp-volume,.playful.fixed-controls .fp-volume,.playful.is-mouseover .fp-play,.playful.fixed-controls .fp-play{opacity:1;filter:progid:DXImageTransform.Microsoft.Alpha(Opacity=100)}
.playful.fixed-controls .fp-volume{display:block}
.playful.fixed-controls .fp-controls{bottom:-35px;}
.is-fullscreen.playful.fixed-controls .fp-controls{bottom:0}
.playful.fixed-controls .fp-time em{bottom:-23px;opacity:1;filter:progid:DXImageTransform.Microsoft.Alpha(Opacity=100);}
.is-fullscreen.playful.fixed-controls .fp-time em{bottom:12px}
.playful.is-disabled .fp-progress{background-color:#999}
.playful .fp-embed{position:absolute;top:12px;left:12px;display:block;width:25px;height:20px;background-position:3px -237px;}
.is-rtl.playful .fp-embed{background-position:22px -237px;left:auto;right:12px}
.playful .fp-embed-code{position:absolute;display:none;top:10px;left:40px;background-color:#333;padding:3px 5px;-webkit-border-radius:3px;-moz-border-radius:3px;border-radius:3px;-webkit-box-shadow:0 0 3px #ccc;-moz-box-shadow:0 0 3px #ccc;box-shadow:0 0 3px #ccc;font-size:12px;}
.playful .fp-embed-code:before{content:'';width:0;height:0;position:absolute;top:2px;left:-10px;border:5px solid transparent;border-right-color:#333}
.is-rtl.playful .fp-embed-code{left:auto;right:40px;}
.is-rtl.playful .fp-embed-code:before{left:auto;right:-10px;border-right-color:transparent;border-left-color:#333}
.playful .fp-embed-code textarea{width:400px;height:16px;font-family:monaco,"courier new",verdana;color:#777;white-space:nowrap;resize:none;overflow:hidden;border:0;outline:0;background-color:transparent;color:#ccc}
.playful .fp-embed-code label{display:block;color:#999}
.playful.is-embedding .fp-embed,.playful.is-embedding .fp-embed-code{display:block;opacity:1;filter:progid:DXImageTransform.Microsoft.Alpha(Opacity=100)}
.playful.aside-time .fp-embed{left:110px;}
.is-rtl.playful.aside-time .fp-embed{left:auto;right:110px}
.playful.aside-time .fp-embed-code{left:140px;}
.is-rtl.playful.aside-time .fp-embed-code{left:auto;right:140px}
.playful.aside-time.is-embedding .fp-time{opacity:1;filter:progid:DXImageTransform.Microsoft.Alpha(Opacity=100)}
.playful.is-long.aside-time .fp-embed{left:130px;}
.is-rtl.playful.is-long.aside-time .fp-embed{left:auto;right:130px}
.playful.no-time .fp-embed{left:12px !important;}
.is-rtl.playful.no-time .fp-embed{left:auto;right:12px !important}
@-moz-keyframes pulse{0%{opacity:0}
100%{opacity:1}
}@-webkit-keyframes pulse{0%{opacity:0}
100%{opacity:1}
}@-o-keyframes pulse{0%{opacity:0}
100%{opacity:1}
}@-ms-keyframes pulse{0%{opacity:0}
100%{opacity:1}
}@keyframes pulse{0%{opacity:0}
100%{opacity:1}
}.playful .fp-controls{background-color:#111}
.playful .fp-timeline,.playful .fp-volumeslider{background-color:#555;background-image:-moz-linear-gradient(rgba(255,255,255,0.01),rgba(255,255,255,0.3));background-image:-webkit-gradient(linear,0 0,0 100%,from(rgba(255,255,255,0.01)),to(rgba(255,255,255,0.3)))}
.playful .fp-buffer{background-color:#eee}
.playful .fp-progress{background-color:#008000}
.playful.is-touch.is-mouseover .fp-progress:before{background-color:#008000}
.playful .fp-volumelevel{background-color:#fff}
.playful .fp-mute{display:block;width:38px;height:20px;background-position:0 -79px;}
.is-rtl.playful .fp-mute{background-position:0 -79px}
.is-muted.playful .fp-mute{background-position:0 -109px;opacity:.85;filter:progid:DXImageTransform.Microsoft.Alpha(Opacity=85)}
.playful .fp-play{background-position:9px -20px;}
.is-rtl.playful .fp-play{background-position:18px -20px}
.is-paused.playful .fp-play{background-position:9px 11px;}
.is-rtl.is-paused.playful .fp-play{background-position:18px 11px}
.playful .fp-timeline,.playful .fp-volumeslider{border:1px inset;border-color:rgba(0,0,0,0.3) rgba(17,17,17,0.05)}
.playful .fp-controls,.playful .fp-progress{background-image:-moz-linear-gradient(rgba(255,255,255,0.3),rgba(255,255,255,0.01));background-image:-webkit-gradient(linear,0 0,0 100%,from(rgba(255,255,255,0.3)),to(rgba(255,255,255,0.01)))}
.playful .fp-timeline,.playful .fp-progress,.playful .fp-buffer,.playful .fp-volumeslider,.playful .fp-volumelevel{-webkit-border-radius:7px;-moz-border-radius:7px;border-radius:7px}
.playful.color-light .fp-controls{background-color:#eee;background-image:-moz-linear-gradient(rgba(0,0,0,0.01),rgba(0,0,0,0.3));background-image:-webkit-gradient(linear,0 0,0 100%,from(rgba(0,0,0,0.01)),to(rgba(0,0,0,0.3)))}
.playful.color-light .fp-timeline,.playful.color-light .fp-volumeslider{border-color:#eee #ccc}
.playful.color-alt .fp-progress,.playful.color-alt .fp-volumelevel{background-color:#111}
.playful.color-alt.is-touch.is-mouseover .fp-progress:before{background-color:#111}
.playful.color-alt2 .fp-progress,.playful.color-alt2 .fp-volumelevel{background-color:#900}
.playful.color-alt2.is-touch.is-mouseover .fp-progress:before{background-color:#900}
